Engine

Struct Engine 

pub struct Engine {
    pub attack_table: AttackTable,
}
The chess engine which has knowledge of the chess rules.
On initialization it generates all static data (like attack tables), so it’s best to only initialize it only once (hence the Arc<>).

Fields

attack_table: AttackTable

Implementations

Source

impl Engine

pub fn initialize() -> Arc<Self>

pub fn generate_moves( &self, game_state: &GameState, ) -> (Vec<ChessMove>, GameStatus)

pub fn is_in_check(&self, board: ChessBoard, color: Color) -> bool

pub fn is_square_attacked( &self, board: ChessBoard, square: u8, opponent_color: Color, ) -> bool

pub fn get_square_threats( &self, board: ChessBoard, square: u8, opponent_color: Color, ) -> BitBoard

pub fn is_promotion(&self, game_state: &GameState, move_to: u8) -> bool

pub fn get_pawn_double_push_target( &self, game_state: &GameState, from: u8, occupied_mask: BitBoard, ) -> Option<u8>